export interface EPCCStore {
  name: string;
}

export interface CreateStoreResponse {
  data: {
    id: string;
  };
}

export interface SwitchStoreResponse {
  title: string;
  status: number;
}

export interface InviteUsersResponse {
  [key as string]: string;
}

export interface StoresResponse {
  data: OrganizationStore[];
  links: {
    current: string;
    first: string;
    last: string;
    next: string;
    prev: string;
  };
  meta: {
    page: {
      limit: number;
      offset: number;
      current: number;
      total: number;
    };
    results: {
      total: number;
    };
  };
}

export interface OrganizationStore {
  id: string;
  name: string;
  store_type: string;
  stripe_customer_id: string;
  type: string;
  ep_disabled: boolean;
  relationships: {
    organization: {
      data: {
        id: string;
        type: string;
      };
    };
  };
  meta: {
    timestamps: {
      created_at: string;
      updated_at: string;
    };
  };
}

export interface EPCCAdminAPI {
  createStore(store: EPCCStore): Promise<CreateStoreResponse>;
  switchSessionToOrg(orgId: string): Promise<SwitchStoreResponse>;
  switchStoreInOrg(storeId: string): Promise<SwitchStoreResponse>;
  getIHCustomerId(): Promise<string>;
  getStores(): Promise<OrganizationStore[]>;
  inviteUsers(storeId: string, email: string[]): Promise<InviteUsersResponse>;
  createIntegrationInstance(ihCustomerId: string, integrationDetails: InstanceDetail): Promise<string>;
  upsertIntegrationInstance(integrationDetails: InstanceDetail);
  getJWT(): Promise<string>;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  integrationHubAuthenticate(jwt: string): Promise<void>;
}

export interface KeyValueMap {
  key: string;
  value: unknown;
}

export interface InstanceDetail {
  instanceName: string;
  instanceDescription: string;
  integrationName: string;
  id?: string;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  configVariables?: ConfigVariable[];
  flowConfigs?: FlowConfig[];
}

export interface ConfigVariable {
  key: string;
  value?: string;
  values?: MultiValueConfigVariable[];
}

export interface FlowConfig {
  apiKeys?: string[];
  flow: string;
}

export interface CreateInstanceResponse {
  instanceId: string;
  authorizeUrls: string[];
}

export interface GetIntegrationResponse {
  flows: FlowDefinitionResponse[];
  integrationId: string;
}

export interface GetInstanceResponse {
  instanceId: string;
  flows: FlowDefinitionResponse[];
  integrationId: string;
  integrationName: string;
  latestIntegrationVersionId: string;
  latestIntegrationVersionNumber: string;
}

export interface FlowDefinitionResponse {
  id: string;
  name: string;
}

export interface UpdateInstanceVersionResponse {
  instanceId: string;
  integrationId: string;
}

export interface UpdateInstanceResponse {
  flows: FlowConfigResponse[];
  authorizeUrls: string[];
}

export interface FlowConfigResponse {
  apiKeys: string[];
  id: string;
}

export interface InputFlowConfig {
  apiKeys?: string[];
  flowId: string;
}

export interface InstancesResponse {
  instance: {
    name: string;
    description: string;
  };
  integration: {
    name: string;
    description: string;
  };
  flowConfigs: FlowConfig[];
  configVariables: ConfigVariableResponse[];
}

export interface ConfigVariableResponse {
  key: string;
  value?: string;
  values?: MultiValueConfigVariable[];
  type?: string;
}

export interface MultiValueConfigVariable {
  name: string;
  value: string;
  type: string;
}

/**
 * Creates a new EPCC store. Requires an Organization-level Application Key for authorization.
 * @param store - The store object containing store details
 * @returns A promise that resolves with the created store response
 */
export function createStore(store: EPCCStore): Promise<CreateStoreResponse>;

/**
 * Fetches all stores for the organization. Requires an Organization-level Application Key for authorization.
 * @returns A promise that resolves with an array of organization stores
 */
export function getStores(): Promise<OrganizationStore[]>;

/**
 * Switches the current session to a specified organization. Requires an Organization-level Application Key for authorization.
 * @param orgId - The ID of the organization to switch to
 * @returns A promise that resolves with the switch response
 */
export function switchSessionToOrg(orgId: string): Promise<SwitchStoreResponse>;

/**
 * Switches to a specific store within the current organization. Requires an Organization-level Application Key for authorization.
 * @param storeId - The ID of the store to switch to
 * @returns A promise that resolves with the switch response
 */
export function switchStoreInOrg(storeId: string): Promise<SwitchStoreResponse>;

/**
 * Fetches the EPCC JWT token for authentication
 * @returns A promise that resolves with the JWT token
 */
export function getJWT(): Promise<string>;

/**
 * Authenticates with the Integrations Hub using a JWT token
 * @param jwt - The JWT token for authentication
 * @returns A promise that resolves when authentication is complete
 */
export function integrationHubAuthenticate(jwt: string): Promise<void>;

/**
 * Retrieves the Integrations Hub Customer ID for the authenticated user
 * @returns A promise that resolves with the customer ID
 * @throws Error if not authenticated with integrationHubAuthenticate first
 */
export function getIHCustomerId(): Promise<string>;

/**
 * Retrieves the current integration ID by its name
 * @param name - The name of the integration
 * @returns A promise that resolves with the integration details
 * @throws Error if not authenticated with integrationHubAuthenticate first
 */
export function getCurrentIntegrationIdByName(name: string): Promise<GetIntegrationResponse>;

/**
 * Retrieves an integration instance by its name
 * @param name - The name of the integration instance
 * @returns A promise that resolves with the instance details
 * @throws Error if not authenticated with integrationHubAuthenticate first
 */
export function getIntegrationInstanceByName(name: string): Promise<GetInstanceResponse>;

/**
 * Creates a new integration instance
 * @param ihCustomerId - The Integrations Hub customer ID
 * @param instanceDetails - Details of the instance to create
 * @param flowConfigs - Optional flow configurations
 * @returns A promise that resolves with the created instance details
 * @throws Error if not authenticated with integrationHubAuthenticate first
 */
export function createIntegrationInstance(
  ihCustomerId: string,
  instanceDetails: InstanceDetail,
  flowConfigs?: InputFlowConfig[]
): Promise<CreateInstanceResponse>;

/**
 * Updates an existing integration instance configuration
 * @param instanceDetails - Details of the instance to update
 * @param flowConfigs - Optional flow configurations
 * @returns A promise that resolves with the update response
 * @throws Error if not authenticated with integrationHubAuthenticate first
 */
export function updateIntegrationInstanceConfiguration(
  instanceDetails: InstanceDetail,
  flowConfigs?: InputFlowConfig[]
): Promise<UpdateInstanceResponse>;

/**
 * Deploys an integration instance
 * @param instanceId - The ID of the instance to deploy
 * @returns A promise that resolves with the configuration state
 * @throws Error if not authenticated with integrationHubAuthenticate first
 */
export function deployIntegrationInstance(instanceId: string): Promise<string>;

/**
 * Upgrades an integration instance to the latest version
 * @param instanceName - The name of the instance to upgrade
 * @param deployNewInstance - Whether to deploy the new instance after upgrade
 * @returns A promise that resolves when the upgrade is complete
 * @throws Error if instance is not found or if upgrade fails
 */
export function upgradeIntegrationInstanceByName(instanceName: string, deployNewInstance?: boolean): Promise<void>;

/**
 * Retrieves all instances for a customer (limited to first 100)
 * @param ihCustomerId - The Integrations Hub customer ID
 * @returns A promise that resolves with the customer instances
 * @throws Error if not authenticated with integrationHubAuthenticate first
 */
export function getCustomerInstances(ihCustomerId: string): Promise<InstancesResponse[]>;

/**
 * Exports all customer integration instances
 * @returns A promise that resolves with all customer instances
 */
export function exportCustomerInstances(): Promise<InstancesResponse[]>;

/**
 * Creates or updates integration instances
 * @param instanceDetails - The instance details to create or update
 * @returns A promise that resolves with the updated instance details
 */
export function upsertIntegrationInstance(...instanceDetails: InstanceDetail[]): Promise<InstanceDetail[]>;

/**
 * Authorizes connections using provided authorization URLs
 * @param authorizeUrls - Array of URLs to authorize
 * @returns A promise that resolves when all authorizations are complete
 */
export function authorizeConnections(authorizeUrls: string[]): Promise<void>;

/**
 * Invites users to a store with seller-admin role
 * @param storeId - The ID of the store to invite users to
 * @param users - Array of user emails to invite
 * @returns A promise that resolves with the invite response
 */
export function inviteUsers(storeId: string, users: string[]): Promise<InviteUsersResponse>; 